<?php
/**
 * Federation Web Service Authentication plugin.
 */

require_once( 'AuthPlugin.php' );
 
class AaiAuthPlugin extends AuthPlugin {
	var $path;
	var $user;
	var $message;
	var $white_list;
	var $aai;
	// cuvati usera ili auth objekt koji ima usera?

	function AaiAuthPlugin($path,$aai,$white_list) {
		$this->path = $path;
		$this->aai = $aai;
		$this->white_list = $white_list;		
	}

	/**
	 * Check whether there exists a user account with the given name.
	 * The name will be normalized to MediaWiki's requirements, so
	 * you might need to munge it (for instance, for lowercase initial
	 * letters).
	 *
	 * @param $username String: username.
	 * @return bool
	 * @public
	 */
	function userExists( $username ) {
		return true;
	}

	/**
	 * Check if a username+password pair is a valid login.
	 * The name will be normalized to MediaWiki's requirements, so
	 * you might need to munge it (for instance, for lowercase initial
	 * letters).
	 *
	 * @param $username String: username.
	 * @param $password String: user password.
	 * @return bool
	 * @public
	 */
	function authenticate( $username, $password ) {		
		$username = strtolower($username);
		if (is_array($this->white_list) && count($this->white_list) > 0) {
			// postoji white lista
			$domain = $this->getDomain($username);
			if (!in_array($domain,$this->white_list)) {
				// domena nije na white listi 
				if ($domain == 'nodomain')
					$this->message = "Nije Vam dozvoljen pristup.";
				else 
					$this->message = "Domeni $domain nije dozvoljen pristup.";
				
				return 
					false;
			}
		}						
		require_once($this->path . 'auth.php');		
		$auth = new Auth($this->path,$this->aai);		
		if ($auth->authenticate($username,$password)) {
			$this->user = $auth->user;
			return true;
		} else {
			$this->message = $auth->get_message();
			return false;
		}
	}

	// dceljak
	function getDomain($username){
		$p = strpos($username,'@');	
		if ($p === false) {
			$domain = 'nodomain';
		} else {
			$domain = substr($username,$p+1);
			if (strlen(trim($domain)) == 0) {
				$domain = 'nodomain';
			}
		}
		return $domain;
	}

	/**
	 * Modify options in the login template.
	 *
	 * @param $template UserLoginTemplate object.
	 * @public
	 */
	function modifyUITemplate( &$template ) {
		$template->set('usedomain',   false); // We do not want a domain name.
		// $template->set('create',      false); // Remove option to create new accounts from the wiki (ja implementirao u formu)
		$template->set('useemail',    false); // Disable the mail new password box.
		$template->set( 'message', 		$this->message); // moja poruka zasto autentikacija nije prosla
	}
	
	/**
	 * Set the domain this plugin is supposed to use when authenticating.
	 *
	 * @param $domain String: authentication domain.
	 * @public
	 */
	function setDomain( $domain ) {
		$this->domain = $domain;
	}

	/**
	 * Check to see if the specific domain is a valid domain.
	 *
	 * @param $domain String: authentication domain.
	 * @return bool
	 * @public
	 */
	function validDomain( $domain ) {
		return true;
	}
	
	/**
	 * When a user logs in, optionally fill in preferences and such.
	 * For instance, you might pull the email address or real name from the
	 * external user database.
	 *
	 * The User object is passed by reference so it can be modified; don't
	 * forget the & on your function declaration.
	 *
	 * @param User $user
	 * @public
	 */
	function updateUser( &$user ) {
		if (isset($this->user) && is_array($this->user)) {
			if (isset($this->user['givenName']) && isset($this->user['sn'])) {
				$user->setRealName($this->user['givenName'] . ' ' . $this->user['sn']);
			}
			if (isset($this->user['mail'])) {
				$user->setEmail($this->user['mail']);
				$user->mEmailAuthenticated = wfTimestampNow();				
			}
		}
		$user->saveSettings();
	}
	
	/**
	 * Return true if the wiki should create a new local account automatically
	 * when asked to login a user who doesn't exist locally but does in the
	 * external auth database.
	 *
	 * If you don't automatically create accounts, you must still create
	 * accounts in some way. It's not possible to authenticate without
	 * a local account.
	 *
	 * This is just a question, and shouldn't perform any actions.
	 *
	 * @return bool
	 * @public
	 */
	function autoCreate() {
		return true;
	}

	/**
	 * Can users change their passwords?
	 *
	 * @return bool
	 */

        function allowPasswordChange() {
		// password se upisuje samo kod instalacije
		if (eregi("/config/index.php$", $_SERVER['SCRIPT_FILENAME'])) 
			return true;
	       else
	      		return false;
	}

	/**
	 * Set the given password in the authentication database.
	 * As a special case, the password may be set to null to request
	 * locking the password to an unusable value, with the expectation
	 * that it will be set later through a mail reset or other method.
	 *
	 * Return true if successful.
	 *
	 * @param $user User object.
	 * @param $password String: password.
	 * @return bool
	 * @public
	 */
	function setPassword( $user, $password ) {	
		return true;
	}

	/**
	 * Update user information in the external authentication database.
	 * Return true if successful.
	 *
	 * @param $user User object.
	 * @return bool
	 * @public
	 */
	function updateExternalDB( $user ) {
		return true;
	}

	/**
	 * Check to see if external accounts can be created.
	 * Return true if external accounts can be created.
	 * @return bool
	 * @public
	 */
	function canCreateAccounts() {
		return false;
	}

	/**
	 * Add a user to the external authentication database.
	 * Return true if successful.
	 *
	 * @param User $user
	 * @param string $password
	 * @return bool
	 * @public
	 */
	function addUser( $user, $password ) {
		return false;
	}

	/**
	 * Return true to prevent logins that don't authenticate here from being
	 * checked against the local database's password fields.
	 *
	 * This is just a question, and shouldn't perform any actions.
	 *
	 * @return bool
	 * @public
	 */
	function strict() {
		return true;
	}

	/**
	 * When creating a user account, optionally fill in preferences and such.
	 * For instance, you might pull the email address or real name from the
	 * external user database.
	 *
	 * The User object is passed by reference so it can be modified; don't
	 * forget the & on your function declaration.
	 *
	 * @param $user User object.
	 * @public
	 */
	function initUser( &$user ) {
		if (isset($this->user) && is_array($this->user)) {
			// $user->setPassword( '' );
			if (isset($this->user['givenName']) && isset($this->user['sn'])) {
				$user->setRealName($this->user['givenName'] . ' ' . $this->user['sn']);
				$user->setOption('nickname',$this->user['givenName'] . ' ' . $this->user['sn']);
			}
			if (isset($this->user['mail'])) {
				$user->setEmail($this->user['email']);
				$user->mEmailAuthenticated = wfTimestampNow();
			}
		}
	}
	
	/**
	 * If you want to munge the case of an account name before the final
	 * check, now is your chance.
	 */
	function getCanonicalName( $username ) {
		// return strtolower($username);	// ne funkcionira vise
		return $username;
	}
}

?>
